##  Sample Code
The YAML snippet below provides sample docker-compose code.

```
version: '3.8'

 services:
  github-agent:
    image: ghcr.io/leanix/leanix-github-agent:v0.1.0
    platform: linux/amd64
    ports:
      - "8080:8080"
    environment:
      - GITHUB_ENTERPRISE_BASE_URL=https://your-url
      - GITHUB_APP_ID={{App id which can be found in the GitHub App page}}
      - PEM_FILE=/privateKey.pem
      - LEANIX_DOMAIN={{YOUR-SUBDOMAIN}}.leanix.net
      - LEANIX_TECHNICAL_USER_TOKEN={{Administrator token generated by EAM}}
    volumes:
      - {{Location of the pem key downloaded from the GitHub app page}}:/privateKey.pem

```



